<?php

namespace Property\Property\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Property\Property\Http\Requests\BalanceRequest;
use Property\Property\Models\Balance;

/**
 * Admin web controller class.
 */
class BalanceWorkflowController extends BaseController
{

    /**
     * Workflow controller function for balance.
     *
     * @param Model   $balance
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(BalanceRequest $request, Balance $balance, $step)
    {

        try {

            $balance->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('property::balance.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/balance/balance/' . $balance->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/balance/balance/' . $balance->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for balance.
     *
     * @param Model   $balance
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Balance $balance, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $balance->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('property::balance.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('property::admin.balance.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('property::admin.balance.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('property::admin.balance.message', $data)->render();

        }

    }
}
