<?php

namespace Property\Property\Policies;

use Litepie\User\Contracts\UserPolicy;
use Property\Property\Models\BalanceType;

class BalanceTypePolicy
{

    /**
     * Determine if the given user can view the balance_type.
     *
     * @param UserPolicy $user
     * @param BalanceType $balance_type
     *
     * @return bool
     */
    public function view(UserPolicy $user, BalanceType $balance_type)
    {
        if ($user->canDo('property.balance_type.view') && $user->isAdmin()) {
            return true;
        }

        return $balance_type->user_id == user_id() && $balance_type->user_type == user_type();
    }

    /**
     * Determine if the given user can create a balance_type.
     *
     * @param UserPolicy $user
     * @param BalanceType $balance_type
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('property.balance_type.create');
    }

    /**
     * Determine if the given user can update the given balance_type.
     *
     * @param UserPolicy $user
     * @param BalanceType $balance_type
     *
     * @return bool
     */
    public function update(UserPolicy $user, BalanceType $balance_type)
    {
        if ($user->canDo('property.balance_type.edit') && $user->isAdmin()) {
            return true;
        }

        return $balance_type->user_id == user_id() && $balance_type->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given balance_type.
     *
     * @param UserPolicy $user
     * @param BalanceType $balance_type
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BalanceType $balance_type)
    {
        return $balance_type->user_id == user_id() && $balance_type->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given balance_type.
     *
     * @param UserPolicy $user
     * @param BalanceType $balance_type
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BalanceType $balance_type)
    {
        if ($user->canDo('property.balance_type.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given balance_type.
     *
     * @param UserPolicy $user
     * @param BalanceType $balance_type
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BalanceType $balance_type)
    {
        if ($user->canDo('property.balance_type.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
