<?php

namespace Property\Property\Providers;

use Litepie\Contracts\Workflow\Workflow as WorkflowContract;
use Litepie\Foundation\Support\Providers\WorkflowServiceProvider as ServiceProvider;

class WorkflowServiceProvider extends ServiceProvider
{
    /**
     * The validators mappings for the package.
     *
     * @var array
     */
    protected $validators = [
        // Bind Property workflow validator
        'Property\Property\Models\Property' => \Property\Property\Workflow\PropertyValidator::class,

        // Bind Project workflow validator
        'Property\Property\Models\Project' => \Property\Property\Workflow\ProjectValidator::class,

        // Bind BalanceType workflow validator
        'Property\Property\Models\BalanceType' => \Property\Property\Workflow\BalanceTypeValidator::class,

        // Bind Balance workflow validator
        'Property\Property\Models\Balance' => \Property\Property\Workflow\BalanceValidator::class,
    ];

    /**
     * The actions mappings for the package.
     *
     * @var array
     */
    protected $actions = [
        // Bind Property workflow actions
        'Property\Property\Models\Property' => \Property\Property\Workflow\PropertyAction::class,

        // Bind Project workflow actions
        'Property\Property\Models\Project' => \Property\Property\Workflow\ProjectAction::class,

        // Bind BalanceType workflow actions
        'Property\Property\Models\BalanceType' => \Property\Property\Workflow\BalanceTypeAction::class,

        // Bind Balance workflow actions
        'Property\Property\Models\Balance' => \Property\Property\Workflow\BalanceAction::class,
    ];

    /**
     * The notifiers mappings for the package.
     *
     * @var array
     */
    protected $notifiers = [
       // Bind Property workflow notifiers
        'Property\Property\Models\Property' => \Property\Property\Workflow\PropertyNotifier::class,

        // Bind Project workflow notifiers
        'Property\Property\Models\Project' => \Property\Property\Workflow\ProjectNotifier::class,

        // Bind BalanceType workflow notifiers
        'Property\Property\Models\BalanceType' => \Property\Property\Workflow\BalanceTypeNotifier::class,

        // Bind Balance workflow notifiers
        'Property\Property\Models\Balance' => \Property\Property\Workflow\BalanceNotifier::class,
    ];

    /**
     * Register any package workflow validation services.
     *
     * @param \Litepie\Contracts\Workflow\Workflow $workflow
     *
     * @return void
     */
    public function boot(WorkflowContract $workflow)
    {
        parent::registerValidators($workflow);
        parent::registerActions($workflow);
        parent::registerNotifiers($workflow);
    }
}
