<?php

namespace Property\Property\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Property\Property\Models\Balance;

class BalanceAction
{
    /**
     * Perform the complete action.
     *
     * @param Balance $balance
     *
     * @return Balance
     */
    public function complete(Balance $balance)
    {
        try {
            $balance->status = 'complete';
            return $balance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Balance $balance
     *
     * @return Balance
     */public function verify(Balance $balance)
    {
        try {
            $balance->status = 'verify';
            return $balance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Balance $balance
     *
     * @return Balance
     */public function approve(Balance $balance)
    {
        try {
            $balance->status = 'approve';
            return $balance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Balance $balance
     *
     * @return Balance
     */public function publish(Balance $balance)
    {
        try {
            $balance->status = 'publish';
            return $balance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Balance $balance
     *
     * @return Balance
     */
    public function archive(Balance $balance)
    {
        try {
            $balance->status = 'archive';
            return $balance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Balance $balance
     *
     * @return Balance
     */
    public function unpublish(Balance $balance)
    {
        try {
            $balance->status = 'unpublish';
            return $balance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
