<?php

namespace Property\Property\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Property\Property\Models\BalanceType;

class BalanceTypeAction
{
    /**
     * Perform the complete action.
     *
     * @param BalanceType $balance_type
     *
     * @return BalanceType
     */
    public function complete(BalanceType $balance_type)
    {
        try {
            $balance_type->status = 'complete';
            return $balance_type->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param BalanceType $balance_type
     *
     * @return BalanceType
     */public function verify(BalanceType $balance_type)
    {
        try {
            $balance_type->status = 'verify';
            return $balance_type->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param BalanceType $balance_type
     *
     * @return BalanceType
     */public function approve(BalanceType $balance_type)
    {
        try {
            $balance_type->status = 'approve';
            return $balance_type->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param BalanceType $balance_type
     *
     * @return BalanceType
     */public function publish(BalanceType $balance_type)
    {
        try {
            $balance_type->status = 'publish';
            return $balance_type->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param BalanceType $balance_type
     *
     * @return BalanceType
     */
    public function archive(BalanceType $balance_type)
    {
        try {
            $balance_type->status = 'archive';
            return $balance_type->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param BalanceType $balance_type
     *
     * @return BalanceType
     */
    public function unpublish(BalanceType $balance_type)
    {
        try {
            $balance_type->status = 'unpublish';
            return $balance_type->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
