<?php

namespace Property\Property\Workflow;

use Property\Property\Models\BalanceType;
use Validator;

class BalanceTypeValidator
{

    /**
     * Determine if the given balance_type is valid for complete status.
     *
     * @param BalanceType $balance_type
     *
     * @return bool / Validator
     */
    public function complete(BalanceType $balance_type)
    {
        return Validator::make($balance_type->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given balance_type is valid for verify status.
     *
     * @param BalanceType $balance_type
     *
     * @return bool / Validator
     */
    public function verify(BalanceType $balance_type)
    {
        return Validator::make($balance_type->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given balance_type is valid for approve status.
     *
     * @param BalanceType $balance_type
     *
     * @return bool / Validator
     */
    public function approve(BalanceType $balance_type)
    {
        return Validator::make($balance_type->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given balance_type is valid for publish status.
     *
     * @param BalanceType $balance_type
     *
     * @return bool / Validator
     */
    public function publish(BalanceType $balance_type)
    {
        return Validator::make($balance_type->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given balance_type is valid for archive status.
     *
     * @param BalanceType $balance_type
     *
     * @return bool / Validator
     */
    public function archive(BalanceType $balance_type)
    {
        return Validator::make($balance_type->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given balance_type is valid for unpublish status.
     *
     * @param BalanceType $balance_type
     *
     * @return bool / Validator
     */
    public function unpublish(BalanceType $balance_type)
    {
        return Validator::make($balance_type->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
