<?php

namespace Property\Property\Workflow;

use Property\Property\Models\Balance;
use Validator;

class BalanceValidator
{

    /**
     * Determine if the given balance is valid for complete status.
     *
     * @param Balance $balance
     *
     * @return bool / Validator
     */
    public function complete(Balance $balance)
    {
        return Validator::make($balance->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given balance is valid for verify status.
     *
     * @param Balance $balance
     *
     * @return bool / Validator
     */
    public function verify(Balance $balance)
    {
        return Validator::make($balance->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given balance is valid for approve status.
     *
     * @param Balance $balance
     *
     * @return bool / Validator
     */
    public function approve(Balance $balance)
    {
        return Validator::make($balance->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given balance is valid for publish status.
     *
     * @param Balance $balance
     *
     * @return bool / Validator
     */
    public function publish(Balance $balance)
    {
        return Validator::make($balance->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given balance is valid for archive status.
     *
     * @param Balance $balance
     *
     * @return bool / Validator
     */
    public function archive(Balance $balance)
    {
        return Validator::make($balance->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given balance is valid for unpublish status.
     *
     * @param Balance $balance
     *
     * @return bool / Validator
     */
    public function unpublish(Balance $balance)
    {
        return Validator::make($balance->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
