<?php

namespace Property\Property\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Property\Property\Models\Property;

class PropertyAction
{
    /**
     * Perform the complete action.
     *
     * @param Property $property
     *
     * @return Property
     */
    public function complete(Property $property)
    {
        try {
            $property->status = 'complete';
            return $property->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Property $property
     *
     * @return Property
     */public function verify(Property $property)
    {
        try {
            $property->status = 'verify';
            return $property->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Property $property
     *
     * @return Property
     */public function approve(Property $property)
    {
        try {
            $property->status = 'approve';
            return $property->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Property $property
     *
     * @return Property
     */public function publish(Property $property)
    {
        try {
            $property->status = 'publish';
            return $property->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Property $property
     *
     * @return Property
     */
    public function archive(Property $property)
    {
        try {
            $property->status = 'archive';
            return $property->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Property $property
     *
     * @return Property
     */
    public function unpublish(Property $property)
    {
        try {
            $property->status = 'unpublish';
            return $property->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
