<?php

namespace Property\Property\Workflow;

use Property\Property\Models\Property;
use Validator;

class PropertyValidator
{

    /**
     * Determine if the given property is valid for complete status.
     *
     * @param Property $property
     *
     * @return bool / Validator
     */
    public function complete(Property $property)
    {
        return Validator::make($property->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given property is valid for verify status.
     *
     * @param Property $property
     *
     * @return bool / Validator
     */
    public function verify(Property $property)
    {
        return Validator::make($property->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given property is valid for approve status.
     *
     * @param Property $property
     *
     * @return bool / Validator
     */
    public function approve(Property $property)
    {
        return Validator::make($property->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given property is valid for publish status.
     *
     * @param Property $property
     *
     * @return bool / Validator
     */
    public function publish(Property $property)
    {
        return Validator::make($property->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given property is valid for archive status.
     *
     * @param Property $property
     *
     * @return bool / Validator
     */
    public function archive(Property $property)
    {
        return Validator::make($property->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given property is valid for unpublish status.
     *
     * @param Property $property
     *
     * @return bool / Validator
     */
    public function unpublish(Property $property)
    {
        return Validator::make($property->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
